@@ -31,9 +31,7 @@
 #ifndef KTNEFATTACH_H
 #define KTNEFATTACH_H
 
-#include <QMap>
 #include <QString>
-#include <QVariant>
 
 #include "ktnefpropertyset.h"
 #include "ktnef_export.h"
